==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_cs.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Jaká to byla vyspělá civilizace. Staletí pod vodou a jejich výtahy ještě jezdí.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Zvláště, když zatlačíme.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Ale jenom dolů.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Vidíš tu lasturu?")


dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")
dialogStr("To je prastarý talisman stavitelů zdviží. Aby jim výtah skvěle Shell.")


dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")
dialogStr("Není ti ta lastura nějak povědomá?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Že se nestydí. Taková zjevná skrytá reklama!")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Ta lebka je mi nějak povědomá.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Všechny lidské lebky vypadají stejně... Na rozdíl od rybích kostřiček.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("To je ale cesta.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Připadám si jako křeček ve šlapacím kole.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Šlapací kolo na ryby? Vždyť máme jen ploutve.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")
dialogStr("Hu húúú húúúúú... Já jsem táádýýý...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")
dialogStr("Húúú, jestli chcete, prozradím vám řešení všech místností...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Húúúú hu húúúú, já vím, proč se potopilo město!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")
dialogStr("Húúúú, proč si mě nikdo nevšímá?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Húúúú hu húúú húúú! Proč mě ignorujete?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hahúúú, holahúúúú, ryby! Všimněte si mě!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_cs.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("Jaká to byla vyspělá civilizace. Staletí pod vodou a jejich výtahy ještě jezdí.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Zvláště, když zatlačíme.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Ale jenom dolů.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Vidíš tu lasturu?")


dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")
dialogStr("To je prastarý talisman stavitelů zdviží. Aby jim výtah skvěle Shell.")


dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")
dialogStr("Není ti ta lastura nějak povědomá?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Že se nestydí. Taková zjevná skrytá reklama!")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Ta lebka je mi nějak povědomá.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Všechny lidské lebky vypadají stejně... Na rozdíl od rybích kostřiček.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("To je ale cesta.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Připadám si jako křeček ve šlapacím kole.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Šlapací kolo na ryby? Vždyť máme jen ploutve.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")
dialogStr("Hu húúú húúúúú... Já jsem táádýýý...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")
dialogStr("Húúú, jestli chcete, prozradím vám řešení všech místností...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Húúúú hu húúúú, já vím, proč se potopilo město!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")
dialogStr("Húúúú, proč si mě nikdo nevšímá?")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Húúúú hu húúú húúú! Proč mě ignorujete?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hahúúú, holahúúúú, ryby! Všimněte si mě!")
